==> contentsquare-3.7.0.tar.gz: android/src/main/kotlin/com/contentsquare/flutter/infrastructure/bridges/XpfInterfaceBridge.kt <==
package com.contentsquare.flutter.infrastructure.bridges

import com.contentsquare.android.api.bridge.xpf.ExternalBridgeInterface
import com.contentsquare.android.api.bridge.xpf.XpfInterface

internal interface XpfInterfaceBridge {

    /**
     * Register an external bridge.
     *
     * @param externalBridge the external bridge to register.
     */
    fun registerExternalBridge(externalBridge: ExternalBridgeInterface)

    /**
     * Unregister an external bridge.
     *
     * @param externalBridge the external bridge to unregister.
     */
    fun unregisterExternalBridge(externalBridge: ExternalBridgeInterface)


    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [XpfInterfaceBridge].
         */
        fun default(): XpfInterfaceBridge {
            return XpfInterfaceBridgeImpl()
        }
    }
}

/**
 * Channel of method in the contentsquare sdk interfaces for xpf.
 */
internal enum class XpfInterfaceChannel(val value: String) {
    /** channel/method called to register an external bridge */
    REGISTER_EXTERNAL_BRIDGE("registerExternalBridge"),

    /** channel/method called to unregister an external bridge */
    UNREGISTER_EXTERNAL_BRIDGE("unregisterExternalBridge")
}


/**
 * Implementation of [XpfInterfaceBridge].
 *
 * @see XpfInterfaceBridge
 */
internal class XpfInterfaceBridgeImpl : XpfInterfaceBridge {
    private val objectInstanceName = "INSTANCE"

    override fun registerExternalBridge(externalBridge: ExternalBridgeInterface) {
        val xpfInterface = XpfInterface::class.java
        val instance = xpfInterface.getDeclaredField(objectInstanceName).get(null)

        xpfInterface.getDeclaredMethod(
                XpfInterfaceChannel.REGISTER_EXTERNAL_BRIDGE.value,
                ExternalBridgeInterface::class.java).run {
                isAccessible = true
                invoke(instance, externalBridge)
        }
    }

    override fun unregisterExternalBridge(externalBridge: ExternalBridgeInterface) {
        val xpfInterface = XpfInterface::class.java
        val instance = xpfInterface.getDeclaredField(objectInstanceName).get(null)
        xpfInterface.getDeclaredMethod(
                XpfInterfaceChannel.UNREGISTER_EXTERNAL_BRIDGE.value,
                ExternalBridgeInterface::class.java).run {
                isAccessible = true
                invoke(instance, externalBridge)
        }
    }
}

==> contentsquare-3.8.0.tar.gz: android/src/main/kotlin/com/contentsquare/flutter/infrastructure/bridges/XpfInterfaceBridge.kt <==
package com.contentsquare.flutter.infrastructure.bridges

import android.webkit.WebView
import com.contentsquare.android.api.bridge.xpf.ExternalBridgeInterface
import com.contentsquare.android.api.bridge.xpf.XpfInterface

internal interface XpfInterfaceBridge {

    /**
     * Register an external bridge.
     *
     * @param externalBridge the external bridge to register.
     */
    fun registerExternalBridge(externalBridge: ExternalBridgeInterface)

    /**
     * Unregister an external bridge.
     *
     * @param externalBridge the external bridge to unregister.
     */
    fun unregisterExternalBridge(externalBridge: ExternalBridgeInterface)

    /**
     * Register a WebView.
     *
     * @param webView the WebView to register.
     * @param id the identifier of WebView in the ViewLight/ViewGraph.
     */
    fun registerWebView(webView: WebView, id: Long)

    /**
     * Unregister a WebView.
     *
     * @param webView the WebView to unregister.
     */
    fun unregisterWebView(webView: WebView)


    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [XpfInterfaceBridge].
         */
        fun default(): XpfInterfaceBridge {
            return XpfInterfaceBridgeImpl()
        }
    }
}

/**
 * Channel of method in the contentsquare sdk interfaces for xpf.
 */
internal enum class XpfInterfaceChannel(val value: String) {
    /** channel/method called to register an external bridge */
    REGISTER_EXTERNAL_BRIDGE("registerExternalBridge"),

    /** channel/method called to unregister an external bridge */
    UNREGISTER_EXTERNAL_BRIDGE("unregisterExternalBridge"),

    /** channel/method called to register a WebView */
    REGISTER_WEBVIEW("registerWebView"),

    /** channel/method called to unregister a WebView */
    UNREGISTER_WEBVIEW("unregisterWebView"),
}


/**
 * Implementation of [XpfInterfaceBridge].
 *
 * @see XpfInterfaceBridge
 */
internal class XpfInterfaceBridgeImpl : XpfInterfaceBridge {
    private val objectInstanceName = "INSTANCE"

    override fun registerExternalBridge(externalBridge: ExternalBridgeInterface) {
        val xpfInterface = XpfInterface::class.java
        val instance = xpfInterface.getDeclaredField(objectInstanceName).get(null)

        xpfInterface.getDeclaredMethod(
                XpfInterfaceChannel.REGISTER_EXTERNAL_BRIDGE.value,
                ExternalBridgeInterface::class.java).run {
                isAccessible = true
                invoke(instance, externalBridge)
        }
    }

    override fun unregisterExternalBridge(externalBridge: ExternalBridgeInterface) {
        val xpfInterface = XpfInterface::class.java
        val instance = xpfInterface.getDeclaredField(objectInstanceName).get(null)
        xpfInterface.getDeclaredMethod(
                XpfInterfaceChannel.UNREGISTER_EXTERNAL_BRIDGE.value,
                ExternalBridgeInterface::class.java).run {
                isAccessible = true
                invoke(instance, externalBridge)
        }
    }

    override fun registerWebView(webView: WebView, id: Long) {
        val xpfInterface = XpfInterface::class.java
        val instance = xpfInterface.getDeclaredField(objectInstanceName).get(null)
        xpfInterface.getDeclaredMethod(
            XpfInterfaceChannel.REGISTER_WEBVIEW.value,
            WebView::class.java, Long::class.java).run {
            isAccessible = true
            invoke(instance, webView, id)
        }
    }

    override fun unregisterWebView(webView: WebView) {
        val xpfInterface = XpfInterface::class.java
        val instance = xpfInterface.getDeclaredField(objectInstanceName).get(null)
        xpfInterface.getDeclaredMethod(
            XpfInterfaceChannel.UNREGISTER_WEBVIEW.value,
            WebView::class.java).run {
            isAccessible = true
            invoke(instance, webView)
        }
    }
}
